.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Trigonometric functions
=======================

**xtensor** provides the following trigonometric functions for xexpressions and scalars:

Defined in ``xtensor/xmath.hpp``

.. _sin-function-reference:
.. doxygenfunction:: sin(E&&)
   :project: xtensor

.. _cos-function-reference:
.. doxygenfunction:: cos(E&&)
   :project: xtensor

.. _tan-function-reference:
.. doxygenfunction:: tan(E&&)
   :project: xtensor

.. _asin-function-reference:
.. doxygenfunction:: asin(E&&)
   :project: xtensor

.. _acos-function-reference:
.. doxygenfunction:: acos(E&&)
   :project: xtensor

.. _atan-function-reference:
.. doxygenfunction:: atan(E&&)
   :project: xtensor

.. _atan2-func-ref:
.. doxygenfunction:: atan2(E1&&, E2&&)
   :project: xtensor

